#include "sentry_screenshot.h"

#include "sentry_core.h"

bool
sentry__screenshot_capture(
    const sentry_path_t *UNUSED(path), uint32_t UNUSED(pid))
{
    return false;
}
